==> tine20-allinone_2019.12.5.tar.bz2: Tasks/js/Tasks-lang-zh_TW-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (Taiwan) (http://www.transifex.com/tine20/tine20/language/zh_TW/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: zh_TW\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""

]
, "Task, Tasks"
: [
  "任務"

]
, "Percent"
: "百分比"

, "Completed"
: "已完成"

, "Due"
: ""

, "Class"
: ""

, "Description"
: ""

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: ""

, "Priority"
: "優先權"

, "Status, Status"
: [
  ""

]
, "Lead"
: ""

, "Telephone"
: ""

, "Email"
: ""

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: ""

, "Summary"
: "總計"

, "Due date"
: "到期日"

, "Add Responsible ..."
: ""

, "Notes"
: "備註"

, "Enter description..."
: "輸入說明"

, "Percentage"
: "百分比"

, "Tasks"
: "任務"

, "to do list, to do lists"
: [
  "工作清單"

]
, "to do lists"
: "工作清單"

, "Quick Search"
: ""

, "Due Date"
: "到期日"

, "Responsible"
: "負責"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "建立時間"

, "Created By"
: ""

, "New Task"
: ""

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "要刪除已選的任務嗎?"

]
, "Attachments"
: ""

, "Tags"
: ""

, "Lead name"
: ""

, "Add a task..."
: "新增任務"

, "All my tasks"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on Tasks startup"
: ""

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Tasks status available"
: ""

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: ""

, "No response"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Task priorities available"
: ""

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: ""

, "low"
: ""

, "normal"
: ""

, "high"
: ""

, "urgent"
: ""

, "manage shared task lists"
: ""

, "Create new shared tasks lists"
: ""

, "manage shared tasks favorites"
: ""

, "Create or update shared tasks favorites"
: ""

, "%s's personal tasks"
: "%s 的個人任務"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: ""

, "My open tasks"
: ""

, "My open tasks this week"
: ""

, "All tasks for me"
: ""

, "All tasks that I am responsible for"
: ""

, "Last modified by me"
: ""

, "All tasks that I have last modified"
: ""

, "Tasks without responsible"
: ""

, "GENDER_Task"
: ""

, "Task"
: "任務"

, "Status"
: ""

, "to do list"
: "工作清單"

, "Do you really want to delete the selected task?"
: "要刪除已選的任務嗎?"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-zh_TW-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (Taiwan) (http://www.transifex.com/tine20/tine20/language/zh_TW/)\nLanguage: zh_TW\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: ""

, "Summary"
: "總計"

, "Due date"
: "到期日"

, "Priority"
: "優先權"

, "Organizer"
: ""

, "Add Responsible ..."
: ""

, "Notes"
: "備註"

, "Enter description..."
: "輸入說明"

, "Percentage"
: "百分比"

, "Status, Status"
: [
  ""

]
, "Completed"
: "已完成"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "要刪除已選的任務嗎?"

]
, "Attachments"
: ""

, "Tags"
: ""

, "Lead name"
: ""

, "Add a task..."
: "新增任務"

, "Due Date"
: "到期日"

, "Percent"
: "百分比"

, "Responsible"
: "負責"

, "Task, Tasks"
: [
  "任務"

]
, "Tasks"
: "任務"

, "to do list, to do lists"
: [
  "工作清單"

]
, "to do lists"
: "工作清單"

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "建立時間"

, "Created By"
: ""

, "New Task"
: ""

, "All my tasks"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on Tasks startup"
: ""

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: ""

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: ""

, "No response"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Task priorities available"
: ""

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: ""

, "low"
: ""

, "normal"
: ""

, "high"
: ""

, "urgent"
: ""

, "%s's personal tasks"
: "%s 的個人任務"

, "GENDER_Task"
: ""

, "Due"
: ""

, "Class"
: ""

, "Description"
: ""

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: ""

, "Telephone"
: ""

, "Email"
: ""

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: ""

, "My open tasks"
: ""

, "My open tasks this week"
: ""

, "All tasks for me"
: ""

, "All tasks that I am responsible for"
: ""

, "Last modified by me"
: ""

, "All tasks that I have last modified"
: ""

, "Tasks without responsible"
: ""

, "manage shared task lists"
: ""

, "Create new shared tasks lists"
: ""

, "manage shared tasks favorites"
: ""

, "Create or update shared tasks favorites"
: ""

, "Status"
: ""

, "Do you really want to delete the selected task?"
: "要刪除已選的任務嗎?"

, "Task"
: "任務"

, "to do list"
: "工作清單"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
